@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@ public:
     explicit AutoCreateScriptDialog(QWidget *parent = nullptr);
     ~AutoCreateScriptDialog() override;
 
-    QString script(QString &requires) const;
+    Q_REQUIRED_RESULT QString script(QString &required) const;
     void setSieveCapabilities(const QStringList &capabilities);
     void setListOfIncludeFile(const QStringList &listOfIncludeFile);
 
