@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -38,14 +38,14 @@ VacationPageWidget::VacationPageWidget(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *lay = new QVBoxLayout(this);
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     mStackWidget = new QStackedWidget;
     lay->addWidget(mStackWidget);
 
     //Main Page
     QWidget *mainPage = new QWidget;
     QVBoxLayout *vbox = new QVBoxLayout;
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     mainPage->setLayout(vbox);
     mVacationWarningWidget = new VacationWarningWidget(this);
     vbox->addWidget(mVacationWarningWidget);
